<!-- PDF embed - full PDF viewer -->
<embed src="{{ output_path }}#toolbar=1&navpanes=1"
       type="application/pdf"
       class="extractor-embed pdf-embed"
       style="width: 100%; height: 100%; min-height: 500px;">
