<!-- YT-DLP embed - video/audio player -->
<div class="extractor-embed ytdlp-embed" style="width: 100%; height: 100%; min-height: 400px; background: #1a1a1a; display: flex; align-items: center; justify-content: center;">
    <video src="{{ output_path }}"
           style="max-width: 100%; max-height: 100%;"
           controls
           preload="metadata">
        Your browser does not support the video tag.
    </video>
</div>
