<!-- Embedded paper view - shows PDF viewer -->
<div class="extractor-embed papersdl-embed" style="width: 100%; max-width: 900px; margin: 0 auto; background: #1a1a1a; padding: 20px; border-radius: 8px;">
    <div style="text-align: center; padding: 15px 0; border-bottom: 1px solid #333; margin-bottom: 20px;">
        <span style="font-size: 32px;">📄</span>
        <h3 style="margin: 10px 0; color: #fff; font-size: 18px;">Scientific Paper</h3>
    </div>
    <div style="width: 100%; height: 500px; background: #2a2a2a; border-radius: 5px; overflow: hidden;">
        <embed src="{{ output_path }}" type="application/pdf" width="100%" height="100%" />
    </div>
    <div style="margin-top: 15px; text-align: center;">
        <a href="{{ output_path }}" download style="color: #4a9eff; text-decoration: none; padding: 10px 20px; background: #2a2a2a; border-radius: 5px; display: inline-block;">
            Download PDF
        </a>
    </div>
</div>
